@@ -1,5 +1,5 @@
 /* -*- c-basic-offset: 2 -*- */
-/* Copyright(C) 2011 Brazil
+/* Copyright(C) 2011-2015 Brazil
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -12,7 +12,7 @@
 
   You should have received a copy of the GNU Lesser General Public
   License along with this library; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
 #include "trie.hpp"
@@ -168,6 +168,10 @@ void Trie::swap(Trie *trie) {
   key_buf_.swap(&trie->key_buf_);
 }
 
+void Trie::flush() {
+  file_.flush();
+}
+
 void Trie::create_file(const char *file_name,
                        UInt64 file_size,
                        UInt32 max_num_keys,
