@@ -1,6 +1,6 @@
 /* -*- c-basic-offset: 2 -*- */
 /*
-  Copyright(C) 2009-2015 Brazil
+  Copyright(C) 2009-2017 Brazil
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -218,14 +218,16 @@ static grn_logger default_logger = {
   default_logger_fin
 };
 
-static grn_logger current_logger = {
-  GRN_LOG_DEFAULT_LEVEL,
-  GRN_LOG_TIME|GRN_LOG_MESSAGE,
-  NULL,
-  NULL,
-  NULL,
-  NULL
-};
+#define INITIAL_LOGGER {                        \
+  GRN_LOG_DEFAULT_LEVEL,                        \
+  GRN_LOG_TIME|GRN_LOG_MESSAGE,                 \
+  NULL,                                         \
+  NULL,                                         \
+  NULL,                                         \
+  NULL                                          \
+}
+
+static grn_logger current_logger = INITIAL_LOGGER;
 
 void
 grn_default_logger_set_max_level(grn_log_level max_level)
@@ -303,6 +305,10 @@ current_logger_fin(grn_ctx *ctx)
   if (current_logger.fin) {
     current_logger.fin(ctx, current_logger.user_data);
   }
+  {
+    grn_logger initial_logger = INITIAL_LOGGER;
+    current_logger = initial_logger;
+  }
 }
 
 static void
@@ -431,7 +437,7 @@ grn_logger_init(void)
 {
   CRITICAL_SECTION_INIT(default_logger_lock);
   if (!current_logger.log) {
-    grn_memcpy(&current_logger, &default_logger, sizeof(grn_logger));
+    current_logger = default_logger;
   }
 }
 
@@ -529,13 +535,15 @@ static grn_query_logger default_query_logger = {
   default_query_logger_fin
 };
 
-static grn_query_logger current_query_logger = {
-  GRN_QUERY_LOG_DEFAULT,
-  NULL,
-  NULL,
-  NULL,
-  NULL
-};
+#define INITIAL_QUERY_LOGGER {                  \
+  GRN_QUERY_LOG_DEFAULT,                        \
+  NULL,                                         \
+  NULL,                                         \
+  NULL,                                         \
+  NULL                                          \
+}
+
+static grn_query_logger current_query_logger = INITIAL_QUERY_LOGGER;
 
 void
 grn_default_query_logger_set_flags(unsigned int flags)
@@ -598,6 +606,10 @@ current_query_logger_fin(grn_ctx *ctx)
   if (current_query_logger.fin) {
     current_query_logger.fin(ctx, current_query_logger.user_data);
   }
+  {
+    grn_query_logger initial_query_logger = INITIAL_QUERY_LOGGER;
+    current_query_logger = initial_query_logger;
+  }
 }
 
 grn_rc
@@ -675,8 +687,7 @@ grn_query_logger_put(grn_ctx *ctx, unsigned int flag, const char *mark,
 void
 grn_query_logger_init(void)
 {
-  grn_memcpy(&current_query_logger,
-             &default_query_logger, sizeof(grn_query_logger));
+  current_query_logger = default_query_logger;
   CRITICAL_SECTION_INIT(default_query_logger_lock);
 }
 
